@@ -9,7 +9,6 @@
 				"Action log"    => array("admin/action", "action.png"),
 				"User switch"   => array("admin/switch", "switch.png")),
 			"Content" => array(
-				"Files"         => array("admin/file", "files.png"),
 				"Hostnames"     => array("admin/hostname", "hostname.gif"),
 				"Menu"          => array("admin/menu", "menu.png"),
 				"News"          => array("admin/news", "news.png"),
@@ -18,6 +17,10 @@
 				"Webservers"    => array("admin/webserver", "webserver.png")));
 
 		public function execute() {
+			if (is_true(DEBUG_MODE)) {
+				$this->output->add_system_message("Website is running in debug mode. Set DEBUG_MODE in settings/website.conf to 'no'.");
+			}
+
 			$access_list = page_access_list($this->db, $this->user);
 			$private_pages = config_file("private_pages");
 
