@@ -13,16 +13,16 @@
 
 			/* Alerts
 			 */
-			$period = ALERT_HOURS." hours";
-
-			$this->output->add_tag("period", $period);
-			$timestamp = date("Y-m-d H:i:s", strtotime("-".$period));
+			$timestamp = date("Y-m-d 00:00:00");
 
 			/* Exploit attempts
 			 */
 			$this->output->open_tag("list", array("title" => "Top exploit attempts"));
 			$list = $this->model->get_top_exploit_attempts($timestamp);
 			foreach ($list as $item) {
+				if ($item["attempts"] <= 2) {
+					break;
+				}
 				$this->output->add_tag("item", $item["hostname"], array("count" => $item["attempts"]));
 			}
 			$this->output->close_tag();
@@ -32,6 +32,9 @@
 			$this->output->open_tag("list", array("title" => "Top bans"));
 			$list = $this->model->get_top_bans($timestamp);
 			foreach ($list as $item) {
+				if ($item["bans"] <= 2) {
+					break;
+				}
 				$this->output->add_tag("item", $item["hostname"], array("count" => $item["bans"]));
 			}
 			$this->output->close_tag();
@@ -41,6 +44,9 @@
 			$this->output->open_tag("list", array("title" => "Top Forbiddens"));
 			$list = $this->model->get_top_forbiddens($timestamp);
 			foreach ($list as $item) {
+				if ($item["forbidden"] <= 2) {
+					break;
+				}
 				$this->output->add_tag("item", $item["hostname"], array("count" => $item["forbidden"]));
 			}
 			$this->output->close_tag();
@@ -50,6 +56,9 @@
 			$this->output->open_tag("list", array("title" => "Top Not Founds"));
 			$list = $this->model->get_top_not_founds($timestamp);
 			foreach ($list as $item) {
+				if ($item["not_found"] <= 2) {
+					break;
+				}
 				$this->output->add_tag("item", $item["hostname"], array("count" => $item["not_found"]));
 			}
 			$this->output->close_tag();
@@ -59,6 +68,9 @@
 			$this->output->open_tag("list", array("title" => "Top Internal Errors"));
 			$list = $this->model->get_top_internal_errors($timestamp);
 			foreach ($list as $item) {
+				if ($item["errors"] <= 2) {
+					break;
+				}
 				$this->output->add_tag("item", $item["hostname"], array("count" => $item["errors"]));
 			}
 			$this->output->close_tag();
