@@ -63,7 +63,14 @@
 
 			$this->output->open_tag("day", array("label" => $this->graphs[$type]));
 			foreach ($stats as $stat) {
-				$this->output->add_tag("stat", $stat["count"], array("label" => $stat["hostname"]));
+				switch ($type) {
+					case "requests":
+					case "bytes_sent":
+						$stat["count"] = $this->model->readable_number($stat["count"]);
+						break;
+				}
+
+				$this->output->record($stat, "stat");
 			}
 			$this->output->close_tag();
 		}
