@@ -6,10 +6,7 @@
 			$filter = new filter($this->db, $this->output);
 			$filter->to_output("requests");
 
-			$begin = date("Y-m-d", strtotime("-".MONITOR_DAYS." days"));
-			$end = date("Y-m-d", strtotime("tomorrow"));
-
-			if (($info = $this->model->get_information($begin, $end, $filter->hostname, $filter->webserver)) === false) {
+			if (($info = $this->model->get_information($filter->hostname, $filter->webserver)) === false) {
 				$this->output->add_tag("result", "Database error.");
 				return;
 			}
