@@ -6,10 +6,7 @@
 			$filter = new filter($this->db, $this->output);
 			$filter->to_output("requests");
 
-			$begin = date("Y-m-d", strtotime("-".MONITOR_DAYS." days"));
-			$end = date("Y-m-d", strtotime("tomorrow"));
-
-			if (($origins = $this->model->get_origins($begin, $end, $filter->hostname, $filter->webserver)) === false) {
+			if (($origins = $this->model->get_origins($filter->hostname, $filter->webserver)) === false) {
 				$this->output->add_tag("result", "Database error.\n");
 				return;
 			}
@@ -24,7 +21,7 @@
 			$this->output->open_tag("origins", array("max" => $max));
 			foreach ($origins as $origin) {
 				$count = $max == 0 ? 0 : (int)(PIXELS * $origin["count"] / $max);
-				if ($count < ORIGINS_MIN_COUNT) {
+				if ($count < $this->settings->origins_min_count) {
 					continue;
 				}
 				$this->output->add_tag("origin", $origin["country"], array("count" => $count));
