@@ -1,13 +1,12 @@
 <?php
 	class referers_controller extends controller {
 		public function execute() {
+			$this->output->add_javascript("jquery/jquery.js");
+
 			$filter = new filter($this->db, $this->output);
 			$filter->to_output("requests");
 
-			$begin = date("Y-m-d", strtotime("-30 day"));
-			$end = date("Y-m-d", strtotime("tomorrow"));
-
-			if (($referers = $this->model->get_referers($begin, $end, $filter->hostname, $filter->webserver)) === false) {	
+			if (($referers = $this->model->get_referers($filter->hostname, $filter->webserver)) === false) {	
 				$this->output->add_tag("result", "Database error.");
 				return;
 			}
@@ -17,7 +16,7 @@
 				$to_output = false;
 
 				foreach ($referers["referers"][$hostname] as $referer) {
-					if ($referer["count"] < REFERER_MIN_COUNT) {
+					if ($referer["count"] < $this->settings->referer_min_count) {
 						continue;
 					}
 
