@@ -9,7 +9,7 @@
 	/* For internal usage. Only change if you know what you're doing!
 	 */
 	define("BANSHEE_VERSION", "3.0");
-	define("MONITOR_VERSION", "0.5");
+	define("MONITOR_VERSION", "0.6");
 	define("ADMIN_ROLE_ID", 1);
 	define("YES", 1);
 	define("NO", 0);
@@ -25,8 +25,7 @@
 
 	/* Hiawatha Monitor settings
 	 */
-	define("MONITOR_DAYS", 30);
-	define("ALERT_HOURS", 6);
+	define("MONITOR_DAYS", 31);
 
 	/* Pre-defined validation strings for valid_input()
 	 */
@@ -41,7 +40,7 @@
 
 	define("VALIDATE_NONEMPTY",     0);
 
-	$preload_settings = array("secret_website_code", "start_page", "default_language",
+	$preload_settings = array("start_page", "default_language",
 		"head_title", "head_description", "head_keywords");
 	$allowed_uploads = array("jpg", "jpeg", "gif", "png", "pdf", "doc", "xls", "zip", "txt");
 
