@@ -288,11 +288,11 @@
 
 		/* Mask transform function
 		 *
-		 * INPUT:  -
+		 * INPUT:  string XSLT filename
 		 * OUTPUT: false
 		 * ERROR:  -
 		 */
-		public function transform() {
+		public function transform($xslt_file) {
 			return false;
 		}
 
@@ -302,41 +302,38 @@
 		 * OUTPUT: -
 		 * ERROR:  -
 		 */
-		public function generate($view = null) {
+		public function generate() {
 			if ($this->disabled) {
 				return;
 			}
 
-			if (($output == null) && $this->page->ajax_request) {
-				$output = "xml";
-			}
-
 			switch ($this->mode) {
 				case "xml":
 					header("Content-Type: text/xml");
-					print $this->document;
+					$result = $this->document;
 					break;
 				case "data":
 					header("Content-Type: text/plain");
-					print $this->document;
+					$result = $this->document;
 					break;
 				case null:
-					if (($html = parent::transform($this->page->view)) === false) {
-						print "XSL Transformation error";
-						return;
+					$xslt_file = "../views/".$this->page->view.".xslt";
+					if (($result = parent::transform($xslt_file)) === false) {
+						$result = "XSL Transformation error";
+						break;
 					}
 
 					/* GZip content encoding
 					 */
 					$encodings = $_SERVER["HTTP_ACCEPT_ENCODING"];
 					$php_gzip = ini_get("zlib.output_compression");
-					if (($encodings !== null) && (strlen($html) >= 1024) && is_false($php_gzip)) {
+					if (($encodings !== null) && (strlen($result) >= 1024) && is_false($php_gzip) && (headers_sent() == false)) {
 						$encodings = explode(",", $encodings);
 						foreach ($encodings as $encoding) {
 							$encoding = trim($encoding);
 							if ($encoding == "gzip") {
 								header("Content-Encoding: gzip");
-								$html = gzencode($html, 6);
+								$result = gzencode($result, 6);
 								break;
 							}
 						}
@@ -347,13 +344,14 @@
 					header("Content-Type: ".$this->content_type);
 					header("Content-Language: ".$this->language);
 					if (is_false($php_gzip)) {
-						header("Content-Length: ".strlen($html));
+						header("Content-Length: ".strlen($result));
 					}
-					print $html;
 					break;
 				default:
-					print "Unknown output type";
+					$result = "Unknown output type";
 			}
+
+			return $result;
 		}
 	}
 ?>
