@@ -7,6 +7,12 @@
 		}
 
 		public function update_hostnames($hostnames) {
+			if (is_array($hostnames) == false) {
+				return false;
+			} else if (count($hostnames) == 0) {
+				return false;
+			}
+
 			if ($this->db->query("update hostnames set visible=%d", 0) === false) {
 				return false;
 			}
