@@ -32,7 +32,7 @@
 
 		public function delete_item($item_id) {
 			$queries = array(
-				array("delete from actions where webserver_id=%d", $item_id),
+				array("delete from events where webserver_id=%d", $item_id),
 				array("delete from host_statistics where webserver_id=%d", $item_id),
 				array("delete from requests where webserver_id=%d", $item_id),
 				array("delete from server_statistics where webserver_id=%d", $item_id),
