@@ -20,8 +20,8 @@
 
 			$query .= " limit %d,%d";
 
-			$timestamp_begin = strtotime($begin);
-			$timestamp_end = strtotime($end);
+			$timestamp_begin = strtotime($begin." 00:00:00");
+			$timestamp_end = strtotime($end." 00:00:00");
 
 			$stats = array();
 			foreach ($this->types as $key) {
@@ -51,6 +51,8 @@
 					$day_end = date("Y-m-d", $entry["timestamp_end"]);
 
 					if ($day == $day_end) {
+						/* Entry within one day
+						 */
 						$percentage = 1;
 					} else if ($entry["timestamp_begin"] < $timestamp_begin) {
 						/* Entry begins before begin time
@@ -58,23 +60,22 @@
 						if (($timespan = $entry["timestamp_end"] - $entry["timestamp_begin"]) == 0) {
 							continue;
 						}
-						$overtime = $timestamp_begin - $entry["timestamp_begin"];
-						$percentage = ($timespan - $overtime) / $timespan;
+						$percentage = ($entry["timestamp_end"] - $timestamp_begin) / $timespan;
+						$day = $day_end;
 					} else if ($entry["timestamp_end"] > $timestamp_end) {
 						/* Entry ends after end time
 						 */
 						if (($timespan = $entry["timestamp_end"] - $entry["timestamp_begin"]) == 0) {
 							continue;
 						}
-						$overtime = $entry["timestamp_end"] - $timestamp_end;
-						$percentage = ($timespan - $overtime) / $timespan;
+						$percentage = ($timestamp_end - $entry["timestamp_begin"]) / $timespan;
 					} else {
 						/* Entry spans two days
 						 */
-						$break = strtotime($day_end." 00:00:00");
 						if (($timespan = $entry["timestamp_end"] - $entry["timestamp_begin"]) == 0) {
 							continue;
 						}
+						$break = strtotime($day_end." 00:00:00");
 						$percentage = ($break - $entry["timestamp_begin"]) / $timespan;
 
 						foreach ($this->types as $key) {
@@ -90,9 +91,9 @@
 				$offset += $limit;
 			} while (count($entries) > 0);
 
-			foreach ($result as &$day) {
-				foreach ($day as &$value) {
-					$value = round($value);
+			foreach ($result as $d => $day) {
+				foreach ($day as $v => $value) {
+					$result[$d][$v] = round($value);
 				}
 			}
 			ksort($result);
@@ -101,7 +102,9 @@
 		}
 
 		public function readable_number($number) {
-			if ($number > 1000000) {
+			if ($number > 1000000000) {
+				return sprintf("%0.1f G", $number / 1000000000);
+			} else if ($number > 1000000) {
 				return sprintf("%0.1f M", $number / 1000000);
 			} else if ($number > 1000) {
 				return sprintf("%0.1f k", $number / 1000);
