@@ -1,10 +1,9 @@
 <?php
 	class operating_system_model extends model {
-		public function get_information($begin, $end, $filter_hostname, $filter_webserver) {
+		public function get_information($filter_hostname, $filter_webserver) {
 			$query = "select o.os, count(*) as count ".
 					 "from requests r, user_agents u, user_agent_browser b, user_agent_os o ".
-					 "where r.user_agent_id=u.id and u.browser_id=b.id and u.os_id=o.id ".
-					 "and timestamp>%s and timestamp<%s";
+					 "where r.user_agent_id=u.id and u.browser_id=b.id and u.os_id=o.id";
 
 			$filter_args = array();
 			if ($filter_hostname != 0) {
@@ -17,7 +16,7 @@
 			}
 			$query .= " group by os order by count desc";
 
-			return $this->db->execute($query, $begin, $end, $filter_args);
+			return $this->db->execute($query, $filter_args);
 		}
 	}
 ?>
