@@ -23,8 +23,8 @@
 	 */
 	if (ini_get("magic_quotes_gpc") == 1) {
 		$superglobals = array(&$_REQUEST, &$_GET, &$_POST, &$_COOKIE);
-		foreach ($superglobals as &$superglobal) {
-			$superglobal = remove_magic_quotes($superglobal);
+		foreach ($superglobals as $i => $superglobal) {
+			$superglobals[$i] = remove_magic_quotes($superglobal);
 		}
 	}
 
@@ -65,7 +65,7 @@
 
 		/* Main menu
 		 */
-		if (is_true(WEBSITE_ONLINE)) {
+		if (is_true(WEBSITE_ONLINE) && $_user->logged_in) {
 			if ($_output->fetch_from_cache("menu") == false) {
 				$_output->start_caching("menu");
 				$menu = new menu($_database, $_output);
@@ -95,6 +95,11 @@
 			$_controller = new $controller_class($_database, $_settings, $_user, $_page, $_output);
 			$_controller->execute();
 			unset($_controller);
+
+			if ($_output->disabled) {
+				print ob_get_clean();
+				exit;
+			}
 		}
 	}
 
@@ -105,7 +110,7 @@
 	/* Errors
 	 */
 	$errors = ob_get_contents();
-	ob_end_clean();
+	ob_clean();
 
 	if ($errors != "") {
 		$error_handler = new website_error_handler($_output, $_settings);
@@ -119,5 +124,7 @@
 
 	/* Output content
 	 */
-	$_output->generate();
+	$output = $_output->generate();
+	$last_errors = ob_get_clean();
+	print $output;
 ?>
